==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/datalakeanalytics/kotlin/inputs/GetFirewallRulePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datalakeanalytics.kotlin.inputs

import com.pulumi.azurenative.datalakeanalytics.inputs.GetFirewallRulePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property accountName The name of the Data Lake Analytics account.
 * @property firewallRuleName The name of the firewall rule to retrieve.
 * @property resourceGroupName The name of the Azure resource group.
 */
public data class GetFirewallRulePlainArgs(
    public val accountName: String,
    public val firewallRuleName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.datalakeanalytics.inputs.GetFirewallRulePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.datalakeanalytics.inputs.GetFirewallRulePlainArgs =
        com.pulumi.azurenative.datalakeanalytics.inputs.GetFirewallRulePlainArgs.builder()
            .accountName(accountName.let({ args0 -> args0 }))
            .firewallRuleName(firewallRuleName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetFirewallRulePlainArgs].
 */
@PulumiTagMarker
public class GetFirewallRulePlainArgsBuilder internal constructor() {
    private var accountName: String? = null

    private var firewallRuleName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The name of the Data Lake Analytics account.
     */
    @JvmName("ntwymfeymlbexqmt")
    public suspend fun accountName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.accountName = mapped
    }

    /**
     * @param value The name of the firewall rule to retrieve.
     */
    @JvmName("dfypkqljtikrpthk")
    public suspend fun firewallRuleName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.firewallRuleName = mapped
    }

    /**
     * @param value The name of the Azure resource group.
     */
    @JvmName("pcxiytbulxnunvvo")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetFirewallRulePlainArgs = GetFirewallRulePlainArgs(
        accountName = accountName ?: throw PulumiNullFieldException("accountName"),
        firewallRuleName = firewallRuleName ?: throw PulumiNullFieldException("firewallRuleName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/datalakeanalytics/kotlin/inputs/GetFirewallRulePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datalakeanalytics.kotlin.inputs

import com.pulumi.azurenative.datalakeanalytics.inputs.GetFirewallRulePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property accountName The name of the Data Lake Analytics account.
 * @property firewallRuleName The name of the firewall rule to retrieve.
 * @property resourceGroupName The name of the Azure resource group.
 */
public data class GetFirewallRulePlainArgs(
    public val accountName: String,
    public val firewallRuleName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.datalakeanalytics.inputs.GetFirewallRulePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.datalakeanalytics.inputs.GetFirewallRulePlainArgs =
        com.pulumi.azurenative.datalakeanalytics.inputs.GetFirewallRulePlainArgs.builder()
            .accountName(accountName.let({ args0 -> args0 }))
            .firewallRuleName(firewallRuleName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetFirewallRulePlainArgs].
 */
@PulumiTagMarker
public class GetFirewallRulePlainArgsBuilder internal constructor() {
    private var accountName: String? = null

    private var firewallRuleName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The name of the Data Lake Analytics account.
     */
    @JvmName("kovvvgtxfyjgmgoi")
    public suspend fun accountName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.accountName = mapped
    }

    /**
     * @param value The name of the firewall rule to retrieve.
     */
    @JvmName("pidxrhanmtitflik")
    public suspend fun firewallRuleName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.firewallRuleName = mapped
    }

    /**
     * @param value The name of the Azure resource group.
     */
    @JvmName("nfrxynsulqlwpngm")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetFirewallRulePlainArgs = GetFirewallRulePlainArgs(
        accountName = accountName ?: throw PulumiNullFieldException("accountName"),
        firewallRuleName = firewallRuleName ?: throw PulumiNullFieldException("firewallRuleName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}
